OC.L10N.register(
    "core",
    {
    "Please select a file." : "Vyberte soubor.",
    "File is too big" : "Soubor je příliš velký",
    "The selected file is not an image." : "Vybraný soubor není obrázek.",
    "The selected file cannot be read." : "Vybraný soubor se nedaří přečíst.",
    "Invalid file provided" : "Zadán neplatný soubor",
    "No image or file provided" : "Neposkytnut žádný obrázek nebo soubor",
    "Unknown filetype" : "Neznámý typ souboru",
    "Invalid image" : "Neplatný obrázek",
    "An error occurred. Please contact your admin." : "Došlo k chybě. Obraťte se na svého správce.",
    "No temporary profile picture available, try again" : "Dočasný profilový obrázek není k dispozici, zkuste to znovu",
    "No crop data provided" : "Nebyla poskytnuta data pro oříznutí obrázku",
    "No valid crop data provided" : "Nebyla poskytnuta platná data pro oříznutí obrázku",
    "Crop is not square" : "Ořez není čtvercový",
    "State token does not match" : "Stavový token neodpovídá",
    "Invalid app password" : "Neplatné heslo pro aplikaci",
    "Could not complete login" : "Přihlášení se nedaří dokončit",
    "Your login token is invalid or has expired" : "Váš přihlašovací token není platný nebo jeho platnost skončila",
    "Password reset is disabled" : "Resetování hesla je vypnuté",
    "Couldn't reset password because the token is invalid" : "Heslo není možné resetovat, protože token není platný",
    "Couldn't reset password because the token is expired" : "Heslo není možné resetovat, protože platnost tokenu skončila",
    "%s password reset" : "reset hesla %s",
    "Password reset" : "Reset hesla",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Pokud chcete resetovat své heslo, klikněte na tlačítko níže. Pokud jste o resetování hesla nežádali, tento e-mail ignorujte.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Pokud chcete resetovat své heslo, klikněte na následující odkaz. Pokud jste o reset nežádali, tento e-mail ignorujte.",
    "Reset your password" : "Resetovat vaše heslo",
    "Nextcloud Server" : "Server Nextcloud",
    "Some of your link shares have been removed" : "Některé vaše sdílené odkazy byly odstraněny",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Kvůli chybě v zabezpečení bylo třeba odstranit některé z sdílení odkazem. Další informace viz odkaz.",
    "Preparing update" : "Příprava na aktualizaci",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Krok opravy:",
    "Repair info:" : "Informace o opravě:",
    "Repair warning:" : "Varování ohledně opravy:",
    "Repair error:" : "Chyba opravy:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Zaktualizujte z příkazového řádku, protože automatická aktualizace je zakázána v config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Kontrola tabulky %s",
    "Turned on maintenance mode" : "Přepnuto do režimu údržby",
    "Turned off maintenance mode" : "Přepnuto zpět z režimu údržby",
    "Maintenance mode is kept active" : "Režim údržby je ponechán",
    "Updating database schema" : "Aktualizace schéma databáze",
    "Updated database" : "Zaktualizována databáze",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Probíhá zjišťování, zda je možné aktualizovat schéma databáze (v závislosti na velikosti databáze to může zabrat delší dobu)",
    "Checked database schema update" : "Aktualizace schéma databáze byla ověřena",
    "Checking updates of apps" : "Kontrola aktualizace aplikací",
    "Checking for update of app \"%s\" in appstore" : "Hledám aktualizaci aplikace  „%s“ v obchodu s aplikacemi",
    "Update app \"%s\" from appstore" : "Aktualizuje se aplikace „%s“ z katalogu aplikací",
    "Checked for update of app \"%s\" in appstore" : "Zkontrolována aktualizace aplikace „%s“ v katalogu aplikací",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Probíhá zjišťování, zda je možné aktualizovat schéma databáze používané pro %s (v závislosti na velikosti databáze to může zabrat delší dobu)",
    "Checked database schema update for apps" : "Aktualizace schéma databáze pro aplikace byla ověřena",
    "Updated \"%1$s\" to %2$s" : "Aktualizováno „%1$s“ na %2$s",
    "Set log level to debug" : "Nastavit úroveň podrobnosti záznamu událostí na stupeň ladění (debug)",
    "Reset log level" : "Vrátit podrobnost záznamu událostí na výchozí úroveň",
    "Starting code integrity check" : "Spouští se kontrola neporušenosti kódu",
    "Finished code integrity check" : "Kontrola neporušenosti kódu dokončena",
    "%s (incompatible)" : "%s (nekompatibilní)",
    "The following apps have been disabled: %s" : "Následující aplikace byly vypnuty: %s",
    "Already up to date" : "Už je aktuální",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Váš webový server ještě není správně nastaven, pro umožnění synchronizace souborů, rozhraní WebDAV pravděpodobně není funkční.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Váš webový server není správně nastaven pro rozpoznání „{url}“. Více informací lze nalézt v naší <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaci</a>.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation page</a>. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Váš webový server není nastaven správně aby přeložil „{url}“. To nejspíš souvisí s nastavením webového serveru, které nebylo aktualizováno pro přímé doručování této složky. Porovnejte svá nastavení vůči dodávaným rewrite pravidlům v „.htaccess“ (pro Apache) nebo těm poskytnutým v dokumentaci (pro Nginx) v jeho <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">stránce v dokumentaci</a>. U Nginx je typicky třeba aktualizovat řádky začínající na „location ~“.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Váš webový server není nastaven správně tak, aby doručoval soubory .woff2. Toto je typicky problém s nastavením Nginx. Pro Nextcloud 15 je třeba ho upravit aby doručoval také soubory .woff2. Porovnejte svoje nastavení Nginx s tím doporučeným v naší <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaci</a>.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Zdá se, že PHP není správně nastaveno pro dotazování proměnných prostředí systému. Test s příkazem getenv(\"PATH\") vrátí pouze prázdnou odpověď.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Nahlédněte do <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">instalační dokumentace ↗</a> kvůli poznámkám pro nastavování PHP a zkontrolujte nastavení PHP na svém serveru, zejména pokud používáte php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Nastavení bylo přepnuto do režimu pouze pro čtení. To brání   změnám prostřednictvím webového rozhraní. Dále při každé aktualizaci, je třeba soubor ručně zpřístupnit pro zápis.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Vaše databáze není spuštěná s úrovní izolace transakcí „READ COMMITTED“. Toto může způsobit problémy při paralelním spouštění více akcí současně.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Modul PHP „fileinfo“ chybí. Důrazně se doporučuje zapnout tento modul pro zajištění lepšího zjišťování MIME typů.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a> for more information." : "Transakční zamykání souborů je vypnuto, což může vést k problémům při souběžném přístupu. Abyste se jim vyhli, zapněte v config.php volbu „filelocking.enabled“. Další informace naleznete v <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaci ↗</a>.",
    "If your installation is not installed at the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (suggestion: \"{suggestedOverwriteCliURL}\")" : "Pokud se vaše instalace nenachází v kořeni domény a používá plánovač systému, může být problém s vytvářením URL adres. Abyste se jim vyhnuli, nastavte volbu „overwrite.cli.url“ v souboru config.php na umístění kořene webu vaší instalace (doporučení: „{suggestedOverwriteCliURL}“)",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Nebylo možné vykonat naplánovanou úlohu z příkazového řádku. Objevily se následující technické chyby:",
    "Last background job execution ran {relativeTime}. Something seems wrong." : "Vykonání poslední naplánované úlohy: {relativeTime}. Vypadá to, že něco není v pořádku.",
    "Check the background job settings" : "Prověřte nastavení cronjob na pozadí",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Tento server nemá funkční připojení k Internetu: Nedaří se připojit k vícero koncovým bodům. Některé moduly jako např. externí úložiště, upozorňování na dostupnost aktualizací, nebo instalace aplikací třetích stran kvůli tomu nebudou fungovat. Přístup k souborům z jiných míst a odesílání e-mailů s upozorněními také nemusí fungovat. Pokud chcete využívat všechny možnosti tohoto serveru, doporučujeme zprovoznit připojení k Internetu.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Nebyla nastavena mezipaměť v paměti. Pokud je dostupná, nastavte ji pro zlepšení výkonu. Další informace lze nalézt v naší <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaci</a>.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "PHP nenalezlo žádný použitelný zdroj náhodnosti, což je silně nedoporučeno z důvodu zabezpečení. Bližší informace naleznete v <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaci</a>.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Nyní používáte PHP {version}. Abyste mohli využívat <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">aktualizace, zlepšující výkonnost a zabezpečení, poskytované autory PHP</a>, přejděte na jeho novější verzi. A to tak rychle, jak to vámi využívaná distribuce operačního sysétmu umožňuje.",
    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 je posledním vydáním, které podporuje PHP 7.2. Nextcloud 21 vyžaduje přinejmenším PHP 7.3.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Nastavení hlaviček reverzní proxy není správné nebo přistupujete na Nextcloud z důvěryhodné proxy. Pokud nepřistupujete k Nextcloud z důvěryhodné proxy, potom je toto bezpečností chyba a může útočníkovi umožnit falšovat IP adresu, kterou NextCloud vidí. Další informace lze nalézt v naší <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaci</a>.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Je nastaven memcached jako distribuovaná cache, ale je nainstalovaný nesprávný PHP modul „memcache“. \\OC\\Memcache\\Memcached podporuje pouze „memcached“ a ne „memcache“. Podívejte se na <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki pro oba moduly</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Některé soubory neprošly kontrolou integrity. Podrobnosti ohledně řešení tohoto problém lze nalézt v <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaci</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Seznam neplatných souborů…</a> / <a href=\"{rescanEndpoint}\">Znovu ověřit…</a>)",
    "The PHP OPcache module is not loaded. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to load it into your PHP installation." : "PHP modul OPcache není načten. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Pro lepší výkon je doporučeno</a> načíst ho do vaší PHP instalace.",
    "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "PHP OPcache není správně nastavené.<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Pro lepší výkon je doporučeno</a> použít v <code>php.ini</code> následující nastavení:",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP funkce „set_time_limit“ není dostupná. To může způsobit ukončení skriptů uprostřed provádění a další problémy s instalací. Doporučujeme tuto funkci povolit.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Vámi využívaná verze PHP nepodporuje FreeType, což bude mít za následky vizuální nedostatky u obrázků profilů a v rozhraní pro nastavování.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Chybí index „{indexName}“ v tabulce „{tableName}“.",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "V databázi chybí některé indexy. Protože přidávání indexů na velkých tabulkách může zabrat nějaký čas, nebyly přidány automaticky. Spuštěním „occ db:add-missing-indices“ je možné tyto chybějící indexy ručně za provozu instance. Po přidání indexů dotazy do těchto tabulek jsou obvykle mnohem rychlejší.",
    "Missing primary key on table \"{tableName}\"." : "Chybí primární klíč v tabulce \"{tableName}\".",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Chybí volitelný sloupec „{columnName}“ v tabulce „{tableName}“.",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "V databázi chybí některé volitelné sloupce. Protože přidání sloupců do rozsáhlých tabulek může trvat dlouho, nebyly přidány automaticky (jsou volitelné). Spuštěním příkazu \"occ db:add-missing-columns\" je možné tyto chybějící sloupce přidat ručně a to za provozu instance. Po přidání se může zlepšit doba reakce a použitelnost některých funkcí.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "V této instanci chybí některé doporučené moduly PHP. Pro lepší výkon a kompatibilitu, je důrazně doporučeno je nainstalovat.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "U některých sloupců tabulek databáze doposud nebyla provedena konverze na datový typ big int. To proto, že změna typů sloupců ve velkých tabulkách může trvat dlouho a proto nebylo provedeno automaticky. Provedení je možné spustit ručně a to spuštěním příkazu „occ db: convert-filecache-bigint“. Ovšem provést lze jen tehdy, když je instance Nexcloud odstavená. Další podrobnosti naleznete <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">na stránce v dokumentaci, pojednávající o tomto</a>.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Jako podpůrná databázová vrstva je nyní používáno SQLite. Pro větší instalace doporučujeme  přejít na jinou databázi.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Toto je doporučeno zejména když používáte pro synchronizaci souborů desktop klienta.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a>." : "Pro migraci na jinou databázi použijte nástroj pro příkazový řádek: „occ db:convert-type“, nebo se podívejte do <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentace ↗</a>.",
    "The PHP memory limit is below the recommended value of 512MB." : "Limit paměti pro PHP je nastaven na níže než doporučenou hodnotu 512MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Složky některých aplikací jsou vlastněny jiným uživatelem, než je ten webového serveru. To může být případ pokud aplikace byly nainstalované ručně. Zkontrolujte oprávnění následujících složek aplikací:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "Jako databáze je používána MySQL, ale nepodporuje 4 bajtové znaky. Aby bylo možné takové (jako například emotikony) bez problémů obsloužit, je doporučeno zapnout v MySQL podporu pro 4 bajtové znaky. Bližší podrobnosti naleznete v <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaci o tomto</a>.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Tato instance používá jako hlavní úložiště objektové úložiště, založené na protokolu S3. Nahrané soubory jsou dočasně ukládány na server a proto je doporučeno mít 50 GB volného prostoru v adresáři temp pro PHP. Podrobnosti o umístění a prostoru, který je k dispozici naleznete v záznamu událostí. Pro navýšení kapacit nasměrujte v php.ini na jiný adresář nebo zvyšte kapacitu stávajícího umístění.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "Přistupujete k vámi využívané instanci přes zabezpečené připojení, nicméně ta vytváří nezabezpečené URL adresy. To nejpravděpodobněji znamená, že se nacházíte za reverzní proxy a přepisovací proměnné nastavení nejsou správně nastavené. Přečtete si tomu věnovanou <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">stránku v dokumentaci</a>. ",
    "Error occurred while checking server setup" : "Při ověřování nastavení serveru došlo k chybě",
    "For more details see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Další podrobnosti naleznete v <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaci</a>.",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Váš adresář data a vaše soubory jsou pravděpodobně dostupné z Internetu. Soubor .htaccess nefunguje. Je velmi doporučeno zajistit, aby tento adresář již nebyl dostupný z internetu, nebo byl přesunut mimo document root webového serveru.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP hlavička „{header}“ není nastavena ve shodě s „{expected}“. To značí možné ohrožení bezpečnosti a soukromí a je doporučeno toto nastavení upravit.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP hlavička „{header}“ není nastavena ve shodě s „{expected}“. To značí možné ohrožení bezpečnosti a soukromí a je doporučeno toto nastavení upravit.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP hlavička „{header}“ neobsahuje „{expected}“. To značí možné ohrožení bezpečnosti a soukromí a je doporučeno toto nastavení upravit.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "HTTP hlavička „{header}“ není nastavena na „{val1}“, „{val2}“, „{val3}“, „{val4}“ nebo „{val5}“. To může odhalovat referer informaci. Viz <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">doporučení W3C ↗</a>.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "HTTP hlavička „Strict-Transport-Security“ není nastavena na přinejmenším „{seconds}“ sekund. Pro lepší zabezpečení je doporučeno zapnout HSTS, jak je popsáno v <a href=\"{docUrl}\" rel=\"noreferrer noopener\">tipech pro zabezpečení ↗</a>.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "Přistupujete přes přes nezabezpečený HTTP protokol. Důrazně doporučujeme nastavit svůj server tak, aby namísto toho vyžadoval HTTPS, jak je popsáno v <a href=\"{docUrl}\">tipech ohledně zabezpečení ↗</a>.",
    "unknown text" : "neznámý text",
    "Hello world!" : "Zdravíme, světe!",
    "sunny" : "slunečno",
    "Hello {name}, the weather is {weather}" : "Zdravíme {name}, počasí je {weather}",
    "Hello {name}" : "Zdravíme, {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Toto výsledky pro vaše hledání<script>alert(1)</script></strong>",
    "new" : "nový",
    "_download %n file_::_download %n files_" : ["stáhnout %n soubor","stáhnout %n soubory","stáhnout %n souborů","stáhnout %n souborů"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Probíhá aktualizace, opuštění této stránky může v některých prostředích přerušit proces.",
    "Update to {version}" : "Aktualizovat na {version}",
    "An error occurred." : "Došlo k chybě.",
    "Please reload the page." : "Načtěte stránku znovu.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Aktualizace nebyla úspěšná. Další informace <a href=\"{url}\">se dočtete v příspěvku na diskuzním fóru</a>, pojednávajícím o tomto problému.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Aktualizace nebyla úspěšná. Nahlaste problém <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">komunitě kolem Nextcloud</a>",
    "Continue to Nextcloud" : "Pokračovat do Nextcloud",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["Aktualizace byla úspěšná. Přesměrování do Nextcloud za %n sekundu.","Aktualizace byla úspěšná. Přesměrování do Nextcloud za %n sekundy.","Aktualizace byla úspěšná. Přesměrování do Nextcloud za %n sekund.","Aktualizace byla úspěšná. Přesměrování do Nextcloud za %n sekundy."],
    "Log in" : "Přihlásit",
    "Logging in …" : "Přihlašování…",
    "Server side authentication failed!" : "Ověření na straně serveru se nezdařilo!",
    "Please contact your administrator." : "Obraťte se na svého správce.",
    "An internal error occurred." : "Došlo k vnitřní chybě.",
    "Please try again or contact your administrator." : "Zkuste to znovu nebo se obraťte na svého správce.",
    "Username or email" : "Uživatelské jméno nebo e-mailová adresa",
    "Password" : "Heslo",
    "Wrong username or password." : "Nesprávné uživatelské jméno nebo heslo.",
    "User disabled" : "Uživatel zakázán",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Bylo rozpoznáno několik neplatných pokusů o přihlášeni z vaší IP adresy. Další přihlášení bude možné za 30 sekund.",
    "Your account is not setup for passwordless login." : "Váš účet nemá nastavené přihlašování se bez hesla.",
    "Passwordless authentication is not supported in your browser." : "Přihlašování se bez hesla není ve vámi používaném prohlížeči podporováno.",
    "Passwordless authentication is only available over a secure connection." : "Ověření se bez hesla je k dispozici pouze přes zabezpečené připojení.",
    "Reset password" : "Resetovat heslo",
    "A password reset message has been sent to the e-mail address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Na e-mailovou adresu, vedenou k tomuto účtu, byla odeslána zpráva s pokyny pro znovunastavení hesla. Pokud jste ji neobdrželi, podívejte se také do složek s nevyžádanou poštou (spam) a/nebo požádejte svého místního správce o pomoc.",
    "If it is not there ask your local administrator." : "Pokud se tam nenachází, zeptejte se svého místního správce.",
    "Couldn't send reset email. Please contact your administrator." : "Nepodařilo se odeslat e-mail pro změnu hesla. Obraťte se na správce.",
    "Password can not be changed. Please contact your administrator." : "Heslo nelze změnit. Obraťte se na svého správce systému.",
    "Back to login" : "Zpět na přihlášení",
    "New password" : "Nové heslo",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Vaše soubory jsou šifrované. Vyresetováním hesla nebude způsob, jak získat vaše data zpět. Pokud nevíte, co dělat, nepokračujte a obraťte se na svého správce. Opravdu chcete pokračovat?",
    "I know what I'm doing" : "Vím co dělám",
    "Resetting password" : "Resetuje se heslo",
    "Recommended apps" : "Doporučené aplikace",
    "Loading apps …" : "Načítání aplikací…",
    "Could not fetch list of apps from the app store." : "Nedaří se získat seznam aplikací z katalogu.",
    "Installing apps …" : "Instalace aplikací…",
    "App download or installation failed" : "Stažení aplikace nebo její instalace se nezdařilo",
    "Can't install this app because it is not compatible" : "Tuto aplikaci nelze nainstalovat, protože není kompatibilní",
    "Can't install this app" : "Tuto aplikaci nelze nainstalovat",
    "Cancel" : "Storno",
    "Schedule work & meetings, synced with all your devices." : "Plánujte si práci a schůzky – synchronizováno napříč všemi vašimi zařízeními.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Uchovávejte si údaje svých kolegů a přátel na jednom místě, aniž by k jejim osobním údajům získal přístup někdo jiný.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Jednoduchý e-mailový klient, propojený se Soubory, Kontakty a Kalendářem.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatování, videohovory, sdílení obrazovky, schůze na dálku a webové konference – ve webovém prohlížeči a mobilních aplikacích.",
    "Collaboratively edit office documents." : "Spolupracujte na upravování kancelářských dokumentů.",
    "Local document editing back-end used by the Collabora Online app." : "Podpůrná vrstva pro místní úpravu dokumentů používána aplikací Collabora Online.",
    "Forgot password?" : "Zapomněli jste heslo?",
    "Log in with a device" : "Přihlásit se pomocí zařízení",
    "Back" : "Zpět",
    "Reset search" : "Resetovat hledání",
    "Search for {name} only" : "Hledat pouze {name}",
    "No results for {query}" : "Pro {query} nic nenalezeno",
    "Start typing to search" : "Hledejte psaním",
    "Loading more results …" : "Načítání dalších výsledků…",
    "Load more results" : "Načíst další výsledky",
    "An error occurred while searching for {type}" : "Došlo k chybě při hledání pro {type}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Aby bylo možné vyhledávat, zadejte alespoň {minSearchLength} znak","Aby bylo možné vyhledávat, zadejte alespoň {minSearchLength} znaky","Aby bylo možné vyhledávat, zadejte alespoň {minSearchLength} znaků","Aby bylo možné vyhledávat, zadejte alespoň {minSearchLength} znaky"],
    "Search {types} …" : "Hledat {types}…",
    "Settings" : "Nastavení",
    "Could not load your contacts" : "Nedaří se načíst vaše kontakty",
    "Search contacts …" : "Prohledat kontakty…",
    "No contacts found" : "Nenalezeny žádné kontakty",
    "Show all contacts …" : "Zobrazit všechny kontakty…",
    "Install the Contacts app" : "Nainstalovat aplikaci Kontakty",
    "Loading your contacts …" : "Načítání vašich kontaktů…",
    "Looking for {term} …" : "Hledání {term}…",
    "No" : "Ne",
    "Yes" : "Ano",
    "No files in here" : "Nejsou zde žádné soubory",
    "New folder" : "Nová složka",
    "No more subfolders in here" : "Nejsou zde žádné další podsložky",
    "Name" : "Název",
    "Size" : "Velikost",
    "Modified" : "Upraveno",
    "\"{name}\" is an invalid file name." : "„{name}“ není platným názvem souboru.",
    "File name cannot be empty." : "Je třeba vyplnit název souboru.",
    "\"/\" is not allowed inside a file name." : "„/“ není povolený znak v názvu souboru.",
    "\"{name}\" is not an allowed filetype" : "„{name}“ není povolený typ souboru",
    "{newName} already exists" : "{newName} už existuje",
    "Choose" : "Vybrat",
    "Copy" : "Zkopírovat",
    "Move" : "Přesunout",
    "Error loading file picker template: {error}" : "Chyba při načítání šablony výběru souborů: {error}",
    "OK" : "OK",
    "Error loading message template: {error}" : "Chyba při načítání šablony zprávy: {error}",
    "read-only" : "pouze pro čtení",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} souborový konflikt","{count} souborové konflikty","{count} souborových konfliktů","{count} souborové konflikty"],
    "One file conflict" : "Jeden konflikt souboru",
    "New Files" : "Nové soubory",
    "Already existing files" : "Už existující soubory",
    "Which files do you want to keep?" : "Které soubory chcete ponechat?",
    "If you select both versions, the copied file will have a number added to its name." : "Pokud zvolíte obě verze, zkopírovaný soubor bude mít název doplněný o číslo.",
    "Continue" : "Pokračovat",
    "(all selected)" : "(vše vybrané)",
    "({count} selected)" : "(vybráno {count})",
    "Error loading file exists template" : "Chyba při načítání šablony existence souboru",
    "Pending" : "Čekající",
    "Copy to {folder}" : "Zkopírovat do {folder}",
    "Move to {folder}" : "Přesunout do  {folder}",
    "Saving …" : "Ukládání…",
    "Authentication required" : "Vyžadováno ověření",
    "This action requires you to confirm your password" : "Tato akce vyžaduje zadání vašeho hesla",
    "Confirm" : "Potvrdit",
    "Failed to authenticate, try again" : "Ověření se nezdařilo, zkuste to znovu",
    "seconds ago" : "před několika sekundami",
    "Connection to server lost" : "Připojení k serveru ztraceno",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problém s načítáním stránky, obnovení za %n sekundu","Problém s načítáním stránky, obnovení za %n sekundy","Problém s načítáním stránky, obnovení za %n sekund","Problém s načítáním stránky, obnovení za %n sekund"],
    "Add to a project" : "Přidat do projektu",
    "Show details" : "Zobrazit podrobnosti",
    "Hide details" : "Skrýt podrobnosti",
    "Rename project" : "Přejmenovat projekt",
    "Failed to rename the project" : "Přejmenování projektu se nezdařilo",
    "Failed to create a project" : "Vytvoření projektu se nezdařilo",
    "Failed to add the item to the project" : "Přidání položky do projektu se nezdařilo",
    "Connect items to a project to make them easier to find" : "Připojte položky k projektu aby je bylo snazší nalézt",
    "Type to search for existing projects" : "Psaním vyhledávejte existující projekty",
    "New in" : "Nové v",
    "View changelog" : "Zobrazit souhrn změn",
    "Very weak password" : "Velmi snadno prolomitelné heslo",
    "Weak password" : "Snadno prolomitelné heslo",
    "So-so password" : "Středně odolné heslo",
    "Good password" : "Dobré heslo",
    "Strong password" : "Odolné heslo",
    "No action available" : "Není dostupná žádná akce",
    "Error fetching contact actions" : "Chyba při získávání akcí kontaktů",
    "Non-existing tag #{tag}" : "Neexistující štítek #{tag}",
    "restricted" : "omezeno",
    "invisible" : "neviditelný",
    "Delete" : "Smazat",
    "Rename" : "Přejmenovat",
    "Collaborative tags" : "Štítky pro spolupráci",
    "No tags found" : "Nenalezeny žádné štítky",
    "Personal" : "Osobní",
    "Users" : "Uživatelé",
    "Apps" : "Aplikace",
    "Admin" : "Správa",
    "Help" : "Nápověda",
    "Access forbidden" : "Přístup zakázán",
    "File not found" : "Soubor nenalezen",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Dokument se nepodařilo na serveru najít. Možná bylo sdílení smazáno nebo skončila jeho platnost?",
    "Back to %s" : "Zpět na %s",
    "Too many requests" : "Příliš mnoho požadavků",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Z vaší sítě bylo příliš mnoho požadavků. Zkuste to později nebo (pokud je toto chyba) se obraťte na svého správce.",
    "Error" : "Chyba",
    "Previous" : "Předchozí",
    "Internal Server Error" : "Vnitřní chyba serveru",
    "The server was unable to complete your request." : "Server nemohl dokončit váš požadavek.",
    "If this happens again, please send the technical details below to the server administrator." : "Pokud se toto stane znovu, pošlete níže uvedené technické podrobnosti správci serveru.",
    "More details can be found in the server log." : "Další podrobnosti naleznete v záznamu událostí serveru.",
    "Technical details" : "Technické podrobnosti",
    "Remote Address: %s" : "Adresa protějšku: %s",
    "Request ID: %s" : "Identifikátor požadavku: %s",
    "Type: %s" : "Typ: %s",
    "Code: %s" : "Kód: %s",
    "Message: %s" : "Zpráva: %s",
    "File: %s" : "Soubor: %s",
    "Line: %s" : "Řádek: %s",
    "Trace" : "Trace",
    "Security warning" : "Varování ohledně zabezpečení",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Váš adresář data a soubory jsou přístupné z Internetu, protože soubor .htaccess nefunguje.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informace o tom, jak správně nastavit svůj server, naleznete v <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaci</a>.",
    "Create an <strong>admin account</strong>" : "Vytvořit <strong>účet správce</strong>",
    "Username" : "Uživatelské jméno",
    "Show password" : "Zobrazit heslo",
    "Storage & database" : "Úložiště a databáze",
    "Data folder" : "Složka s daty",
    "Configure the database" : "Nastavit databázi",
    "Only %s is available." : "Je k dispozici pouze %s.",
    "Install and activate additional PHP modules to choose other database types." : "Aby bylo možné vybrat jiné typy databáze je třeba nainstalovat a povolit dodatečné PHP moduly.",
    "For more details check out the documentation." : "Podrobnosti naleznete v dokumentaci.",
    "Database user" : "Uživatel databáze",
    "Database password" : "Heslo do databáze",
    "Database name" : "Název databáze",
    "Database tablespace" : "Tabulkový prostor databáze",
    "Database host" : "Stroj na kterém se nachází databáze",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zadejte port spolu s názvem hostitele (t. j., localhost:5432).",
    "Performance warning" : "Varování ohledně výkonu",
    "You chose SQLite as database." : "Zvolíte jako databázi SQLite.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite by mělo být použito pouze pro opravdu malé a vývojové instance. Pro produkční použití doporučujeme použít robustnější databázové řešení.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Pokud používáte klienty pro synchronizaci souborů, je použití SQLite silně nedoporučeno.",
    "Install recommended apps" : "Nainstalovat doporučené aplikace",
    "Calendar, Contacts, Talk, Mail & Collaborative editing" : "Kalendář, Kontakty, Talk, E-mail a upravování dokumentů ve spolupráci s ostatními",
    "Finish setup" : "Dokončit nastavení",
    "Finishing …" : "Dokončování…",
    "Need help?" : "Potřebujete nápovědu?",
    "See the documentation" : "Viz dokumentace",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Zdá se, že se pokoušíte přeinstalovat svou instanci NextCloud. Nicméně ve vašem adresáři s nastaveními chybí soubor CAN_INSTALL. Aby bylo možné pokračovat, takový tam vytvořte.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nedaří se ze složky s nastaveními odstranit soubor CAN_INSTALL. Odstraňte ho proto ručně.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Tato aplikace potřebuje pro správnou funkčnost JavaScript. {linkstart}Povolte ho{linkend} a stránku znovu načtěte.",
    "Get your own free account" : "Získejte svůj vlastní účet zdarma",
    "Skip to main content" : "Přeskočit a přejít k hlavnímu obsahu",
    "Skip to navigation of app" : "Přeskočit na navigaci aplikace",
    "More apps" : "Více aplikací",
    "More" : "Více",
    "More apps menu" : "Nabídka dalších aplikací",
    "Contacts" : "Kontakty",
    "Contacts menu" : "Nabídka kontaktů",
    "Settings menu" : "Nabídka nastavení",
    "Confirm your password" : "Potvrdit heslo",
    "Connect to your account" : "Propojit s vaším účtem",
    "Please log in before granting %1$s access to your %2$s account." : "Přihlaste se abyste mohli %1$s udělit přístup k vašemu %2$s účtu.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Pokud se nepokoušíte nastavit nové zařízení či aplikaci, někdo se pokouší vás ošálit a získat tak přístup k vašim datům. V takovém případě nepokračujte a obraťte se na svého správce systémů.",
    "App token" : "Token aplikace",
    "Grant access" : "Udělit přístup",
    "Alternative log in using app token" : "Alternativní přihlášení pomocí tokenu aplikace",
    "Account access" : "Přístup k účtu",
    "You are about to grant %1$s access to your %2$s account." : "Chystáte se udělit %1$s přístup ke svému %2$s účtu.",
    "Account connected" : "Účet připojen",
    "Your client should now be connected!" : "Váš klient by nyní měl být připojen!",
    "You can close this window." : "Toto okno je možné zavřít",
    "This share is password-protected" : "Toto sdílení je chráněno heslem",
    "The password is wrong. Try again." : "Chybné heslo. Zkuste to znovu.",
    "Two-factor authentication" : "Dvoufaktorové přihlášení",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Bylo zapnuto vylepšené zabezpečení pro tento účet. Zvolte druhý faktor pro ověřování:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nedaří se načíst ani jednu ze zapnutých metod dvouúrovňového ověřování. Obraťte se na svého správce.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Je vynucováno dvoufázové ověřování ale to pro váš účet není nastaveno. Obraťte o pomoc na svého správce.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Je vynucováno dvoufázové ověřování ale to pro váš účet není nastaveno. Pokračujte nastavením dvoufázového ověřování.",
    "Set up two-factor authentication" : "Nastavit dvoufázové ověřování",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Je vynucováno dvoufázové ověřování ale to pro váš účet není nastaveno. Přihlaste se použitím nějakého ze svých záložních kódů nebo se obraťte o pomoc na svého správce.",
    "Use backup code" : "Použít záložní kód",
    "Cancel login" : "Zrušit přihlášení",
    "Setup two-factor authentication" : "Nastavit dvoufázové ověřování",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Vylepšené zabezpečení je vynuceno vaším účtem. Zvolte, kterého poskytovatele nastavit:",
    "Error while validating your second factor" : "Chyba při ověřování druhého faktoru",
    "Access through untrusted domain" : "Přístup prostřednictvím nedůvěryhodné domény",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Obraťte se na svého správce. Pokud jste jím vy, upravte v souboru s nastaveními config/config.php parametr „trusted_domains“ podle příkladu v config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Další informace o tom, jak toto nastavit jsou k dispozici v %1$sdokumentaci%2$s.",
    "App update required" : "Vyžadována aktualizace aplikace",
    "%1$s will be updated to version %2$s" : "%1$s bude aktualizováno na verzi %2$s",
    "The following apps will be updated:" : "Následující aplikace budou aktualizovány:",
    "These incompatible apps will be disabled:" : "Tyto nekompatibilní aplikace budou vypnuty:",
    "The theme %s has been disabled." : "Motiv vzhledu %s byl vypnut.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Před provedením dalšího kroku se ujistěte, že je zazálohována databáze a složky s nastaveními a daty.",
    "Start update" : "Spustit aktualizaci",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "U větších instalací, abyste zabránili překračování časového limitu, můžete namísto toho spustit v adresáři, ve kterém je nainstalováno, spustit:",
    "Detailed logs" : "Podrobné záznamy událostí",
    "Update needed" : "Je třeba provést aktualizaci",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Použijte aktualizační příkazový řádek, protože máte velkou instanci s více než 50 uživateli.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pro pomoc, nahlédněte do <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentace</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Beru na vědomí, že při aktualizaci skrze webové rozhraní hrozí nebezpečí překročení časového limitu požadavku, který může vyústit ve ztrátu dat. Mám pro takový případ zálohu a vím, jak ji v případě nezdaru obnovit.",
    "Upgrade via web on my own risk" : "Na vlastní nebezpečí aktualizovat skrze web",
    "Maintenance mode" : "Režim údržby",
    "This %s instance is currently in maintenance mode, which may take a while." : "Tato instance %s se právě nachází v režimu údržby a ta může chvíli trvat.",
    "This page will refresh itself when the instance is available again." : "Tato stránka se automaticky znovu načte, jakmile bude tato instance opět dostupná.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Pokud se tato zpráva objevuje opakovaně nebo nečekaně, obraťte se správce systému.",
    "Following apps have been disabled: %s" : "Následující aplikace byly vypnuty: %s",
    "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "Nyní používáte PHP 5.6. Stávající hlavní verze Nextcloud je poslední, která tuto verzi podporuje. Aby bylo možné přejít na Nextcloud 14, bude třeba přejít na PHP verze 7.0 a novější.",
    "Use of the the built in php mailer is no longer supported. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Please update your email server settings ↗<a/>." : "Použití odesílání e-mailů, vestavěného v php už není podporováno. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Aktualizujte nastavení svého e-mailového serveru ↗<a/>.",
    "({scope})" : "({scope})",
    "Searching other places" : "Prohledávání ostatních umístění",
    "No search results in other folders for {tag}{filter}{endtag}" : "Žádné výsledky v dalších složkách pro {tag}{filter}{endtag}",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} nález v další složce","{count} nálezy v dalších složkách","{count} nálezů v dalších složkách","{count} nálezy v dalších složkách"],
    "Nextcloud {app}" : "Nextcloud {app}",
    "Local document editing back-end used by the OnlyOffice app." : "Místně nainstalovaná vykonávající část pro úpravu dokumentů, využívaná aplikací OnlyOffice.",
    "Saving..." : "Ukládání…",
    "Calendar, Contacts, Talk, Mail & OnlyOffice" : "Kalendář, Kontakty, Talk, E-mail a OnlyOffice",
    "Search" : "Hledat",
    "These apps will be updated:" : "Následující aplikace budou aktualizovány:"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
